@@ -1,46 +1,46 @@
+from __future__ import annotations
+
 import asyncio
 import time
-from typing import Dict
 
-from zeroconf import ServiceBrowser, ServiceStateChange, Zeroconf
+from zeroconf import DNSQuestionType, ServiceBrowser, ServiceStateChange, Zeroconf
 
 from ..device import Device
 
-_devices: Dict[str,
+_devices: dict[str,
                Device] = {}
 
 
-async def async_discover_network() -> Dict[str, Device]:
+async def async_discover_network() -> dict[str, Device]:
     """
     Discover all devices that expose the devolo device API via mDNS asynchronous.
 
     :return: Devices accessible via serial number.
     """
-    browser = ServiceBrowser(Zeroconf(), "_dvl-deviceapi._tcp.local.", [_add])
+    browser = ServiceBrowser(Zeroconf(), "_dvl-deviceapi._tcp.local.", [_add], question_type=DNSQuestionType.QM)
     await asyncio.sleep(3)
     browser.cancel()
     return _devices
 
 
-def discover_network() -> Dict[str, Device]:
+def discover_network() -> dict[str, Device]:
     """
     Discover devices that expose the devolo device API via mDNS synchronous.
 
     :return: Devices accessible via serial number.
     """
-    browser = ServiceBrowser(Zeroconf(), "_dvl-deviceapi._tcp.local.", [_add])
+    browser = ServiceBrowser(Zeroconf(), "_dvl-deviceapi._tcp.local.", [_add], question_type=DNSQuestionType.QM)
     time.sleep(3)
     browser.cancel()
     return _devices
 
 
-def _add(zeroconf: Zeroconf, service_type: str, name: str, state_change: ServiceStateChange):
+def _add(zeroconf: Zeroconf, service_type: str, name: str, state_change: ServiceStateChange) -> None:
     """" Create a device object to each matching device. """
     if state_change is not ServiceStateChange.Added:
         return
 
-    service_info = zeroconf.get_service_info(service_type, name)
-    if service_info is None:
+    if (service_info := zeroconf.get_service_info(service_type, name)) is None:
         return
 
     info = Device.info_from_service(service_info)
